This project is written based on the project written by Fang Li and
various contributors:

CUSTOM Django Saml2 Auth
-----------------
- Custom Project Author: Cláudio Givisiez

- Original Project Author: Fang Li